@@ -274,10 +274,10 @@ class CursorWrapper() :
         except MySQLdb.OperationalError, e:
             error_no = e.args[0]
             if 2000 <= error_no < 3000  :
-                self.farm.cursor = None
+                self.farm._cursor = None
             raise
         except MySQLdb.ProgrammingError, e:
             if e.args[0] == 2014:
-                self.farm.cursor = None
+                self.farm._cursor = None
             raise
 
